@@ -1,7 +1,5 @@
-
-
-#ifndef EC_HTTP_H
-#define EC_HTTP_H
+#ifndef ETTERCAP_HTTP_H
+#define ETTERCAP_HTTP_H
 
 EC_API_EXTERN int http_fields_init(void);
 
