@@ -1,7 +1,5 @@
-
-
-#ifndef EC_PASSIVE_H
-#define EC_PASSIVE_H
+#ifndef ETTERCAP_PASSIVE_H
+#define ETTERCAP_PASSIVE_H
 
 EC_API_EXTERN int is_open_port(u_int8 proto, u_int16 port, u_int8 flags);
 EC_API_EXTERN void print_host(struct host_profile *h); 
