@@ -1,7 +1,5 @@
-
-
-#ifndef EC_SIGNAL_H
-#define EC_SIGNAL_H
+#ifndef ETTERCAP_SIGNAL_H
+#define ETTERCAP_SIGNAL_H
 
 EC_API_EXTERN void signal_handler(void);
 
