@@ -15,9 +15,9 @@
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
 
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+    You should have received a copy of the GNU General Public License along
+    with this program; if not, write to the Free Software Foundation, Inc.,
+    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 */
 
@@ -64,6 +64,9 @@ FUNC_DECODER(dissector_mongodb)
 
    //suppress unused warning
    (void)end;
+   (void) DECODE_DATA; 
+   (void) DECODE_DATALEN;
+   (void) DECODED_LEN;
 
    if (FROM_SERVER("mongodb", PACKET)) {
       if (PACKET->DATA.len < 13)
@@ -71,7 +74,7 @@ FUNC_DECODER(dissector_mongodb)
 
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_mongodb));
       /* if the session does not exist... */
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -ENOTFOUND) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) {
          unsigned char *noncep  = memmem(ptr, PACKET->DATA.len, "nonce", 5);
          unsigned char *gnoncep  = memmem(ptr, PACKET->DATA.len, "getnonce\x00", 9);
          unsigned char *keyp  = memmem(ptr, PACKET->DATA.len, "authenticate\x00", 12);
@@ -99,7 +102,7 @@ FUNC_DECODER(dissector_mongodb)
          }
       }
       else {
-              if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
+              if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS) {
                       conn_status = (struct mongodb_status *) s->data;
                       if (PACKET->DATA.len < 16)
                               return NULL;
@@ -118,7 +121,7 @@ FUNC_DECODER(dissector_mongodb)
    } else {
       dissect_create_ident(&ident, PACKET, DISSECT_CODE(dissector_mongodb));
 
-      if (session_get(&s, ident, DISSECT_IDENT_LEN) == ESUCCESS) {
+      if (session_get(&s, ident, DISSECT_IDENT_LEN) == E_SUCCESS) {
          conn_status = (struct mongodb_status *) s->data;
          if (PACKET->DATA.len < 16)
                  return NULL;
