@@ -60,7 +60,7 @@ void capture_stop(struct iface_env *iface)
 
    snprintf(thread_name, sizeof(thread_name), "capture[%s]", iface->name);
    pid = ec_thread_getpid(thread_name);
-   if(!pthread_equal(pid, EC_PTHREAD_NULL))
+   if(!pthread_equal(pid, ec_thread_getpid(NULL)))
       ec_thread_destroy(pid);
 }
 
@@ -167,6 +167,24 @@ void capture_getifs(void)
                    
 }
 
+/*
+ * return default interface
+ */
+char* capture_default_if(void)
+{
+   /*
+    * as per deprecation message of pcap_lookupdev() the new way to determine
+    * the default interface, is to use the first interface detected by the call
+    * of pcap_findalldevs(). This is already determined in capture_getifs() and
+    * stored in EC_GBL_PCAP->ifs
+    */
+
+   if (EC_GBL_PCAP && EC_GBL_PCAP->ifs)
+      return EC_GBL_PCAP->ifs->name;
+
+   return NULL;
+}
+
 /*
  * check if the given file is a pcap file
  */
