@@ -53,11 +53,32 @@
 /* don't include kerberos. RH sux !! */
 #define OPENSSL_NO_KRB5 1
 #include <openssl/ssl.h>
+#ifdef DEBUG
+   #include <openssl/err.h>
+#endif
 
 #if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
 #define HAVE_OPAQUE_RSA_DSA_DH 1 /* since 1.1.0 -pre5 */
 #endif
 
+#if (OPENSSL_VERSION_NUMBER >= 0x10002000L)
+#define HAVE_OPENSSL_1_0_2
+#endif
+
+#if (OPENSSL_VERSION_NUMBER <= 0x100020700L)
+/* prior 1.0.2g TLS_client_method macro wasn't available */
+#define TLS_client_method SSLv23_client_method
+#define TLS_server_method SSLv23_server_method
+#endif
+
+#if (OPENSSL_VERSION_NUMBER >= 0x10100000L)
+#define HAVE_OPENSSL_1_1_0
+#endif
+
+#if (OPENSSL_VERSION_NUMBER >= 0x10101000L)
+#define HAVE_OPENSSL_1_1_1
+#endif
+
 #define BREAK_ON_ERROR(x,y,z) do {  \
    if (x == -E_INVALID) {            \
       SAFE_FREE(z.DATA.disp_data);  \
@@ -94,6 +115,11 @@ struct accepted_entry {
    SSL *ssl[2];
    u_char status;
    X509 *cert;
+#ifdef HAVE_OPENSSL_1_1_1
+   unsigned int tls_handshake_state;
+#define SSL_CLIENTHELLO_INTERCEPTED 1
+   char *hostname;
+#endif
    #define SSL_CLIENT 0
    #define SSL_SERVER 1
 };
@@ -115,6 +141,9 @@ struct sslw_ident {
 
 #define TSLEEP (50*1000) /* 50 milliseconds */
 
+#ifdef HAVE_OPENSSL_1_1_0
+static SSL_CONF_CTX *ssl_conf_client, *ssl_conf_server;
+#endif
 static SSL_CTX *ssl_ctx_client, *ssl_ctx_server;
 static EVP_PKEY *global_pk;
 static u_int16 number_of_services;
@@ -140,6 +169,10 @@ static void ssl_wrap_fini(void);
 static int sslw_ssl_connect(SSL *ssl_sk);
 static int sslw_ssl_accept(SSL *ssl_sk);
 static int sslw_remove_sts(struct packet_object *po);
+#ifdef HAVE_OPENSSL_1_1_1
+static int sslw_clienthello_cb(SSL *ssl_sk, int *alert, void *arg);
+static char* sslw_get_clienthello_sni(SSL *ssl);
+#endif
 
 /*******************************************/
 
@@ -173,7 +206,7 @@ void sslw_dissect_move(char *name, u_int16 port)
       if(!strcmp(name, le->name)) {
          DEBUG_MSG("sslw_dissect_move: %s [%u]", name, port);
          le->sslw_port = port;
-	 
+
       /* Move to zero means disable */
       if (port == 0) {
          LIST_REMOVE(le, next);
@@ -241,6 +274,10 @@ static void ssl_wrap_fini(void)
 
    SSL_CTX_free(ssl_ctx_server);
    SSL_CTX_free(ssl_ctx_client);
+#ifdef HAVE_OPENSSL_1_1_0
+   SSL_CONF_CTX_free(ssl_conf_client);
+   SSL_CONF_CTX_free(ssl_conf_server);
+#endif
 
    /* remove redirects */
    ec_redirect_cleanup();
@@ -352,8 +389,8 @@ EC_THREAD_FUNC(sslw_start)
    }
 
    return NULL;
-   
-}	 
+
+}
 
 /* 
  * Filter SSL related packets and create NAT sessions.
@@ -366,7 +403,7 @@ static void sslw_hook_handled(struct packet_object *po)
    /* We have nothing to do with this packet */
    if (!sslw_is_ssl(po))
       return;
-     
+
    /* If it's an ssl packet don't forward */
    po->flags |= PO_DROPPED;
    
@@ -374,7 +411,7 @@ static void sslw_hook_handled(struct packet_object *po)
    if ( (po->flags & PO_FORWARDABLE) && 
         (po->L4.flags & TH_SYN) &&
         !(po->L4.flags & TH_ACK) ) {
-	
+
       sslw_create_session(&s, PACKET);
 
 #ifndef OS_LINUX
@@ -382,7 +419,7 @@ static void sslw_hook_handled(struct packet_object *po)
       memcpy(s->data, &po->L3.dst, sizeof(struct ip_addr));
       session_put(s);
 #else
-	SAFE_FREE(s); /* Just get rid of it */
+      SAFE_FREE(s); /* Just get rid of it */
 #endif
    } else /* Pass only the SYN for conntrack */
       po->flags |= PO_IGNORE;
@@ -394,18 +431,15 @@ static void sslw_hook_handled(struct packet_object *po)
  */
 static int sslw_is_ssl(struct packet_object *po)
 {
-   struct listen_entry *le;
-   
    /* If it's already coming from ssl wrapper 
     * or the connection is not TCP */ 
    if (po->flags & PO_FROMSSL || po->L4.proto != NL_TYPE_TCP) 
       return 0;
 
-   LIST_FOREACH(le, &listen_ports, next) {
-      if (ntohs(po->L4.dst) == le->sslw_port ||
-          ntohs(po->L4.src) == le->sslw_port)
-         return 1;
-   }
+   /* check if packet matches one of the registered redirects */
+   if (ec_redirect_lookup(po) == E_SUCCESS)
+      return 1;
+
    return 0;
 }
 
@@ -472,13 +506,13 @@ static void sslw_bind_wrapper(void)
 #endif
 
       if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
-               EC_REDIR_PROTO_IPV4, NULL, NULL,
+               EC_REDIR_PROTO_IPV4, NULL,
                le->sslw_port, le->redir_port) != E_SUCCESS)
         FATAL_ERROR("Can't insert firewall redirects");
 
 #ifdef WITH_IPV6
       if (ec_redirect(EC_REDIR_ACTION_INSERT, le->name,
-               EC_REDIR_PROTO_IPV6, NULL, NULL,
+               EC_REDIR_PROTO_IPV6, NULL,
                le->sslw_port, le->redir_port) != E_SUCCESS)
         FATAL_ERROR("Can't insert firewall redirects");
 #endif
@@ -493,7 +527,7 @@ static int sslw_sync_conn(struct accepted_entry *ae)
 {      
    if(sslw_get_peer(ae) != E_SUCCESS)
          return -E_INVALID;
-	 
+
    if(sslw_connect_server(ae) != E_SUCCESS)
          return -E_INVALID;
 
@@ -532,6 +566,53 @@ static int sslw_ssl_connect(SSL *ssl_sk)
    return -E_INVALID;
 }
 
+/*
+ * ClientHello Callback to intercept SSL handshake after ClientHello
+ */
+#ifdef HAVE_OPENSSL_1_1_1
+static int sslw_clienthello_cb(SSL *ssl, int *alert, void *arg)
+{
+   (void) alert;
+   struct accepted_entry *ae;
+
+   ae = (struct accepted_entry *)arg;
+
+   /* extract hostname value from SNI extension */
+   ae->hostname = sslw_get_clienthello_sni(ssl);
+
+   if (ae->tls_handshake_state != SSL_CLIENTHELLO_INTERCEPTED) {
+      ae->tls_handshake_state = SSL_CLIENTHELLO_INTERCEPTED;
+      /* suspend client side TLS handshake */
+      return SSL_CLIENT_HELLO_RETRY;
+   }
+
+   return SSL_CLIENT_HELLO_SUCCESS;
+
+}
+
+static char* sslw_get_clienthello_sni(SSL *ssl)
+{
+   const unsigned char* sni;
+   size_t len;
+   uint8_t sni_type;
+   uint16_t val_len;
+   // uint16_t sni_len;
+
+   if (SSL_client_hello_get0_ext(ssl, TLSEXT_TYPE_server_name, &sni, &len)) {
+      if (len > 5) {
+         // sni_len = sni[0] << 8 | sni[1];
+         sni_type = sni[2];
+         val_len = sni[3] << 8 | sni[4];
+
+         if (sni_type == TLSEXT_NAMETYPE_host_name)
+            return strndup(sni+5, val_len);
+      }
+   }
+
+   return NULL;
+}
+#endif
+
 
 /* 
  * Perform a blocking SSL_accept with a
@@ -548,10 +629,22 @@ static int sslw_ssl_accept(SSL *ssl_sk)
          return E_SUCCESS;
 
       ssl_err = SSL_get_error(ssl_sk, ret);
+
+#ifdef HAVE_OPENSSL_1_1_1
+      /* return successfully if handshake has been suspended by callback */
+      if (ssl_err == SSL_ERROR_WANT_CLIENT_HELLO_CB)
+         return E_SUCCESS;
+#endif
       
-      /* there was an error... */
-      if (ssl_err != SSL_ERROR_WANT_READ && ssl_err != SSL_ERROR_WANT_WRITE) 
+      /* there was an error...  but only if it's not just pending further progress */
+      if (ssl_err != SSL_ERROR_WANT_READ && ssl_err != SSL_ERROR_WANT_WRITE) {
+#ifdef DEBUG
+         char error_msg[256], *error;
+         error = ERR_error_string(ERR_get_error(), error_msg);
+         DEBUG_MSG("sslw_ssl_accept(): SSL_accept() failed with '%s'", error);
+#endif
          return -E_INVALID;
+      }
       
       /* sleep a quirk of time... */
       ec_usleep(TSLEEP);
@@ -572,15 +665,32 @@ static int sslw_sync_ssl(struct accepted_entry *ae)
 
    X509 *server_cert;
    
+#ifdef HAVE_OPENSSL_1_1_1
+   /* Set a Callback for the SSL client context to pause the Client Handshake */
+   SSL_CTX_set_client_hello_cb(ssl_ctx_client, sslw_clienthello_cb, (void*)ae);
+#endif
+
    ae->ssl[SSL_SERVER] = SSL_new(ssl_ctx_server);
    SSL_set_connect_state(ae->ssl[SSL_SERVER]);
    SSL_set_fd(ae->ssl[SSL_SERVER], ae->fd[SSL_SERVER]);
    ae->ssl[SSL_CLIENT] = SSL_new(ssl_ctx_client);
    SSL_set_fd(ae->ssl[SSL_CLIENT], ae->fd[SSL_CLIENT]);
+
+#ifdef HAVE_OPENSSL_1_1_1
+   /* Begin SSL handshake to extract SNI - then suspend by callback */
+   if (sslw_ssl_accept(ae->ssl[SSL_CLIENT]) != E_SUCCESS)
+      return -E_INVALID;
+
+   if (ae->hostname)
+      /* set SNI for server-side connection */
+      SSL_set_tlsext_host_name(ae->ssl[SSL_SERVER], ae->hostname);
+#endif
     
+   /* Connect to actual SSL server */
    if (sslw_ssl_connect(ae->ssl[SSL_SERVER]) != E_SUCCESS) 
       return -E_INVALID;
 
+   /* Extract certificate from actual SSL server */
    /* XXX - NULL cypher can give no certificate */
    if ( (server_cert = SSL_get_peer_certificate(ae->ssl[SSL_SERVER])) == NULL) {
       DEBUG_MSG("Can't get peer certificate");
@@ -588,20 +698,27 @@ static int sslw_sync_ssl(struct accepted_entry *ae)
    }
 
    if (!EC_GBL_OPTIONS->ssl_cert) {
-   	/* Create the fake certificate */
-   	ae->cert = sslw_create_selfsigned(server_cert);  
-   	X509_free(server_cert);
+      /* Create the fake certificate based on actual certificate */
+      ae->cert = sslw_create_selfsigned(server_cert);  
+      X509_free(server_cert);
 
-   	if (ae->cert == NULL)
-      		return -E_INVALID;
+      if (ae->cert == NULL)
+         return -E_INVALID;
 
-   	SSL_use_certificate(ae->ssl[SSL_CLIENT], ae->cert);
+      /* use faked certificate for further SSL client connection */
+      SSL_use_certificate(ae->ssl[SSL_CLIENT], ae->cert);
 
    }
    
+   /* continue SSL handshake with SSL client */
    if (sslw_ssl_accept(ae->ssl[SSL_CLIENT]) != E_SUCCESS) 
       return -E_INVALID;
 
+#ifdef HAVE_OPENSSL_1_1_1
+   /* TLS handshake done - SNI hostname not longer required: free */
+   SAFE_FREE(ae->hostname);
+#endif
+
 
    return E_SUCCESS;   
 }
@@ -724,7 +841,7 @@ static int sslw_read_data(struct accepted_entry *ae, u_int32 direction, struct p
       /* XXX - Is it necessary? */
       if (len == 0)
          return -E_INVALID;
-	       
+
       if (ret_err == SSL_ERROR_WANT_READ || ret_err == SSL_ERROR_WANT_WRITE)
          return -E_NOTHANDLED;
       else
@@ -816,7 +933,7 @@ static int sslw_write_data(struct accepted_entry *ae, u_int32 direction, struct
       /* XXX - Set a proper sleep time */
       if (not_written)
          ec_usleep(SEC2MICRO(1));
-	 	 
+
    } while (not_written);
          
    return E_SUCCESS;
@@ -908,8 +1025,8 @@ static void sslw_initialize_po(struct packet_object *po, u_char *p_data)
       SAFE_CALLOC(po->DATA.data, 1, UINT16_MAX);
    } else {
       if (po->DATA.data != p_data) {
-      	  SAFE_FREE(po->DATA.data);
-          po->DATA.data = p_data;
+         SAFE_FREE(po->DATA.data);
+         po->DATA.data = p_data;
       }
    }
       
@@ -934,6 +1051,7 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
 {   
    X509 *out_cert;
    X509_EXTENSION *ext;
+   const EVP_MD *md;
    int index = 0;
    
    if ((out_cert = X509_new()) == NULL)
@@ -971,8 +1089,22 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
       }
    }
 
+   /* take over SAN extension from peer certificate */
+   index = X509_get_ext_by_NID(server_cert, NID_subject_alt_name, index);
+   if (index >= 0) {
+      X509_add_ext(out_cert, X509_get_ext(server_cert, index), -1);
+   }
+
+   /* grab digest algorithm from peer certificate */
+   md = EVP_get_digestbynid(X509_get_signature_nid(server_cert));
+   if (md == NULL) {
+      DEBUG_MSG("Error determining message digest algorithm for signing.");
+      /* Falling back to SHA256 signing algorithm which is the default in TLS1.3 */
+      md = EVP_sha256();
+   }
+
    /* Self-sign our certificate */
-   if (!X509_sign(out_cert, global_pk, EVP_sha1())) {
+   if (!X509_sign(out_cert, global_pk, md)) {
       X509_free(out_cert);
       DEBUG_MSG("Error self-signing X509");
       return NULL;
@@ -981,7 +1113,6 @@ static X509 *sslw_create_selfsigned(X509 *server_cert)
    return out_cert;
 }
 
-
 /* 
  * Initialize SSL stuff 
  */
@@ -989,39 +1120,71 @@ static void sslw_init(void)
 {
    SSL *dummy_ssl=NULL;
 
+#ifndef HAVE_OPENSSL_1_1_0
    SSL_library_init();
+#endif
 
    /* Create the two global CTX */
-   ssl_ctx_client = SSL_CTX_new(SSLv23_server_method());
-   ssl_ctx_server = SSL_CTX_new(SSLv23_client_method());
+   ssl_ctx_client = SSL_CTX_new(TLS_server_method());
+   ssl_ctx_server = SSL_CTX_new(TLS_client_method());
 
    ON_ERROR(ssl_ctx_client, NULL, "Could not create client SSL CTX");
    ON_ERROR(ssl_ctx_server, NULL, "Could not create server SSL CTX");
 
+#ifdef HAVE_OPENSSL_1_0_2
+   SSL_CTX_set_ecdh_auto(ssl_ctx_client, 1);
+   SSL_CTX_set_ecdh_auto(ssl_ctx_server, 1);
+#endif
+
+#ifdef HAVE_OPENSSL_1_1_0
+   ssl_conf_client = SSL_CONF_CTX_new();
+   ssl_conf_server = SSL_CONF_CTX_new();
+   SSL_CONF_CTX_set_flags(ssl_conf_client, SSL_CONF_FLAG_FILE);
+   SSL_CONF_CTX_set_flags(ssl_conf_server, SSL_CONF_FLAG_FILE);
+
+   SSL_CONF_CTX_set_ssl_ctx(ssl_conf_client, ssl_ctx_client);
+   SSL_CONF_CTX_set_ssl_ctx(ssl_conf_server, ssl_ctx_server);
+
+   /* Backward compatibility for older TLS versions and ciphers */
+   SSL_CONF_cmd(ssl_conf_client, "MinProtocol", "TLSv1");
+   SSL_CONF_cmd(ssl_conf_server, "MinProtocol", "TLSv1");
+   SSL_CONF_cmd(ssl_conf_client, "CipherString", "DEFAULT");
+   SSL_CONF_cmd(ssl_conf_server, "CipherString", "DEFAULT");
+#endif
+
    if(EC_GBL_OPTIONS->ssl_pkey) {
-	/* Get our private key from the file specified from cmd-line */
-	DEBUG_MSG("Using custom private key %s", EC_GBL_OPTIONS->ssl_pkey);
-	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, EC_GBL_OPTIONS->ssl_pkey, SSL_FILETYPE_PEM) == 0) {
-		FATAL_ERROR("Can't open \"%s\" file : %s", EC_GBL_OPTIONS->ssl_pkey, strerror(errno));
-	}
+      /* Get our private key from the file specified from cmd-line */
+      DEBUG_MSG("Using custom private key %s", EC_GBL_OPTIONS->ssl_pkey);
+      if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client,
+               EC_GBL_OPTIONS->ssl_pkey, SSL_FILETYPE_PEM) == 0) {
+         FATAL_ERROR("Can't open \"%s\" file : %s",
+               EC_GBL_OPTIONS->ssl_pkey, strerror(errno));
+      }
 
-	if (EC_GBL_OPTIONS->ssl_cert) {
-		if (SSL_CTX_use_certificate_file(ssl_ctx_client, EC_GBL_OPTIONS->ssl_cert, SSL_FILETYPE_PEM) == 0) {
-			FATAL_ERROR("Can't open \"%s\" file : %s", EC_GBL_OPTIONS->ssl_cert, strerror(errno));
-		}
+      if (EC_GBL_OPTIONS->ssl_cert) {
+         if (SSL_CTX_use_certificate_file(ssl_ctx_client,
+                  EC_GBL_OPTIONS->ssl_cert, SSL_FILETYPE_PEM) == 0) {
+            FATAL_ERROR("Can't open \"%s\" file : %s",
+                  EC_GBL_OPTIONS->ssl_cert, strerror(errno));
+         }
 
-		if (!SSL_CTX_check_private_key(ssl_ctx_client)) {
-			FATAL_ERROR("Certificate \"%s\" does not match private key \"%s\"", EC_GBL_OPTIONS->ssl_cert, EC_GBL_OPTIONS->ssl_pkey);
-		}
-	}
+         if (!SSL_CTX_check_private_key(ssl_ctx_client)) {
+            FATAL_ERROR("Certificate \"%s\" does not match private key \"%s\"",
+                  EC_GBL_OPTIONS->ssl_cert, EC_GBL_OPTIONS->ssl_pkey);
+         }
+      }
    } else {
-   	/* Get our private key from our cert file */
-   	if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, INSTALL_DATADIR "/" PROGRAM "/" CERT_FILE, SSL_FILETYPE_PEM) == 0) {
-      		DEBUG_MSG("sslw -- SSL_CTX_use_PrivateKey_file -- trying ./share/%s",  CERT_FILE);
+      /* Get our private key from our cert file */
+      if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client,
+               INSTALL_DATADIR"/"PROGRAM"/"CERT_FILE, SSL_FILETYPE_PEM) == 0) {
+            DEBUG_MSG("sslw -- SSL_CTX_use_PrivateKey_file -- trying ./share/%s",
+                  CERT_FILE);
 
-      		if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client, "./share/" CERT_FILE, SSL_FILETYPE_PEM) == 0)
-         		FATAL_ERROR("Can't open \"./share/%s\" file : %s", CERT_FILE, strerror(errno));
-   	}
+            if (SSL_CTX_use_PrivateKey_file(ssl_ctx_client,
+                     "./share/" CERT_FILE, SSL_FILETYPE_PEM) == 0)
+               FATAL_ERROR("Can't open \"./share/%s\" file : %s",
+                     CERT_FILE, strerror(errno));
+      }
    }
 
    dummy_ssl = SSL_new(ssl_ctx_client);
@@ -1056,8 +1219,8 @@ EC_THREAD_FUNC(sslw_child)
       DEBUG_MSG("FAILED TO FIND PEER");
       SAFE_FREE(ae);
       ec_thread_exit();
-   }	    
-	    
+   }
+
    if ((ae->status & SSL_ENABLED) && 
       sslw_sync_ssl(ae) == -E_INVALID) {
       sslw_wipe_connection(ae);
@@ -1080,7 +1243,7 @@ EC_THREAD_FUNC(sslw_child)
 
          ret_val = sslw_read_data(ae, direction, &po);
          BREAK_ON_ERROR(ret_val,ae,po);
-	 
+
          /* if we have data to read */
          if (ret_val == E_SUCCESS) {
             data_read = 1;
@@ -1090,16 +1253,16 @@ EC_THREAD_FUNC(sslw_child)
 
             if (po.flags & PO_DROPPED)
                continue;
-	
+
             ret_val = sslw_write_data(ae, !direction, &po);
             BREAK_ON_ERROR(ret_val,ae,po);
-	    
+
             if ((po.flags & PO_SSLSTART) && !(ae->status & SSL_ENABLED)) {
                ae->status |= SSL_ENABLED; 
                ret_val = sslw_sync_ssl(ae);
                BREAK_ON_ERROR(ret_val,ae,po);
             }
-	    
+
             sslw_initialize_po(&po, po.DATA.data);
          }  
       }
@@ -1116,52 +1279,52 @@ EC_THREAD_FUNC(sslw_child)
 
 static int sslw_remove_sts(struct packet_object *po)
 {
-	u_char *ptr;
-	u_char *end;
-	u_char *h_end;
-	size_t len = po->DATA.len;
-	size_t slen = strlen("\r\nStrict-Transport-Security:");
+   u_char *ptr;
+   u_char *end;
+   u_char *h_end;
+   size_t len = po->DATA.len;
+   size_t slen = strlen("\r\nStrict-Transport-Security:");
 
-	if (!memmem(po->DATA.data, po->DATA.len, "\r\nStrict-Transport-Security:", slen)) {
-		return -E_NOTFOUND;
-	}
+   if (!memmem(po->DATA.data, po->DATA.len, "\r\nStrict-Transport-Security:", slen)) {
+      return -E_NOTFOUND;
+   }
 
-	ptr = po->DATA.data;
-	end = ptr + po->DATA.len;
+   ptr = po->DATA.data;
+   end = ptr + po->DATA.len;
 
-	len = end - ptr;
+   len = end - ptr;
 
-	ptr = (u_char*)memmem(ptr, len, "\r\nStrict-Transport-Security:", slen);
-	ptr += 2;
+   ptr = (u_char*)memmem(ptr, len, "\r\nStrict-Transport-Security:", slen);
+   ptr += 2;
 
-	h_end = (u_char*)memmem(ptr, len, "\r\n", 2);
-	h_end += 2;
+   h_end = (u_char*)memmem(ptr, len, "\r\n", 2);
+   h_end += 2;
 
-	size_t before_header = ptr - po->DATA.data;
-	size_t header_length = h_end - ptr;
-	size_t new_len = 0;
+   size_t before_header = ptr - po->DATA.data;
+   size_t header_length = h_end - ptr;
+   size_t new_len = 0;
 
-	u_char *new_html;
-	SAFE_CALLOC(new_html, len, sizeof(u_char));
+   u_char *new_html;
+   SAFE_CALLOC(new_html, len, sizeof(u_char));
 
-	BUG_IF(new_html == NULL);
+   BUG_IF(new_html == NULL);
 
-	memcpy(new_html, po->DATA.data, before_header);
-	new_len += before_header;
+   memcpy(new_html, po->DATA.data, before_header);
+   new_len += before_header;
 
-	memcpy(new_html+new_len, h_end, (len - header_length) - before_header);
-	new_len += (len - header_length) - before_header;
+   memcpy(new_html+new_len, h_end, (len - header_length) - before_header);
+   new_len += (len - header_length) - before_header;
 
 
-	memset(po->DATA.data, '\0', po->DATA.len);
+   memset(po->DATA.data, '\0', po->DATA.len);
 
-	memcpy(po->DATA.data, new_html, new_len);
-	po->DATA.len = new_len;
+   memcpy(po->DATA.data, new_html, new_len);
+   po->DATA.len = new_len;
 
-	po->flags |= PO_MODIFIED;
+   po->flags |= PO_MODIFIED;
 
 
-	return E_SUCCESS;
+   return E_SUCCESS;
 
 }
 
