@@ -36,7 +36,7 @@ void curses_sniff_live(void)
 
    wdg_create_object(&menu, WDG_MENU, WDG_OBJ_WANT_FOCUS | WDG_OBJ_ROOT_OBJECT);
 
-   wdg_set_title(menu, GBL_VERSION, WDG_ALIGN_RIGHT);
+   wdg_set_title(menu, EC_GBL_VERSION, WDG_ALIGN_RIGHT);
    wdg_set_color(menu, WDG_COLOR_SCREEN, EC_COLOR);
    wdg_set_color(menu, WDG_COLOR_WINDOW, EC_COLOR_MENU);
    wdg_set_color(menu, WDG_COLOR_FOCUS, EC_COLOR_FOCUS);
@@ -46,12 +46,12 @@ void curses_sniff_live(void)
    
    wdg_menu_add(menu, menu_targets);
    
-   if (GBL_SNIFF->type != SM_BRIDGED)
+   if (EC_GBL_SNIFF->type != SM_BRIDGED)
       wdg_menu_add(menu, menu_hosts);
    
    wdg_menu_add(menu, menu_view);
    
-   if (GBL_SNIFF->type != SM_BRIDGED)
+   if (EC_GBL_SNIFF->type != SM_BRIDGED)
       wdg_menu_add(menu, menu_mitm);
    
    wdg_menu_add(menu, menu_filters);
