@@ -46,7 +46,7 @@ static void curses_start_sniffing(void)
    DEBUG_MSG("curses_start_sniffing");
    
    /* start the sniffing method */
-   EXECUTE(GBL_SNIFF->start);
+   EXECUTE(EC_GBL_SNIFF->start);
 }
 
 static void curses_stop_sniffing(void)
@@ -54,7 +54,7 @@ static void curses_stop_sniffing(void)
    DEBUG_MSG("curses_stop_sniffing");
    
    /* terminate the sniffing engine */
-   EXECUTE(GBL_SNIFF->cleanup);
+   EXECUTE(EC_GBL_SNIFF->cleanup);
 }
 
 
