@@ -81,20 +81,22 @@ static void toggle_resolve(void)
    struct hosts_list *hl;
 
    /* resolution already set */
-   if (GBL_OPTIONS->resolve) {
+   if (EC_GBL_OPTIONS->resolve) {
       tag_resolve[0] = ' ';
-      GBL_OPTIONS->resolve = 0;
+      EC_GBL_OPTIONS->resolve = 0;
+      resolv_thread_fini();
       return;
    } 
    
    DEBUG_MSG("toggle_resolve: activate name resolution");
 
-   /* set the option */
+   /* set the option and activate resolution threads */
    tag_resolve[0] = '*';
-   GBL_OPTIONS->resolve = 1;
+   EC_GBL_OPTIONS->resolve = 1;
+   resolv_thread_init();
    
    /* run through the current hosts list and trigger resolution */
-   LIST_FOREACH(hl, &GBL_HOSTLIST, next) {
+   LIST_FOREACH(hl, &EC_GBL_HOSTLIST, next) {
       if (hl->hostname)
          continue;
       host_iptoa(&hl->ip, name);
@@ -152,30 +154,30 @@ static void refresh_stats(void)
    if (!(wdg_stats->flags & WDG_OBJ_FOCUSED))
       return;
    
-   wdg_window_print(wdg_stats, 1, 1, "Received packets    : %8lld", GBL_STATS->ps_recv);
-   wdg_window_print(wdg_stats, 1, 2, "Dropped packets     : %8lld  %.2f %% ", GBL_STATS->ps_drop, 
-          (GBL_STATS->ps_recv) ? (float)GBL_STATS->ps_drop * 100 / GBL_STATS->ps_recv : 0 );
-   wdg_window_print(wdg_stats, 1, 3, "Forwarded packets   : %8lld  bytes: %8lld ", GBL_STATS->ps_sent, GBL_STATS->bs_sent);
+   wdg_window_print(wdg_stats, 1, 1, "Received packets    : %8lld", EC_GBL_STATS->ps_recv);
+   wdg_window_print(wdg_stats, 1, 2, "Dropped packets     : %8lld  %.2f %% ", EC_GBL_STATS->ps_drop, 
+          (EC_GBL_STATS->ps_recv) ? (float)EC_GBL_STATS->ps_drop * 100 / EC_GBL_STATS->ps_recv : 0 );
+   wdg_window_print(wdg_stats, 1, 3, "Forwarded packets   : %8lld  bytes: %8lld ", EC_GBL_STATS->ps_sent, EC_GBL_STATS->bs_sent);
   
-   wdg_window_print(wdg_stats, 1, 5, "Current queue len   : %d/%d ", GBL_STATS->queue_curr, GBL_STATS->queue_max);
-   wdg_window_print(wdg_stats, 1, 6, "Sampling rate       : %d ", GBL_CONF->sampling_rate);
+   wdg_window_print(wdg_stats, 1, 5, "Current queue len   : %d/%d ", EC_GBL_STATS->queue_curr, EC_GBL_STATS->queue_max);
+   wdg_window_print(wdg_stats, 1, 6, "Sampling rate       : %d ", EC_GBL_CONF->sampling_rate);
    
    wdg_window_print(wdg_stats, 1, 8, "Bottom Half received packet : pck: %8lld  bytes: %8lld", 
-         GBL_STATS->bh.pck_recv, GBL_STATS->bh.pck_size);
+         EC_GBL_STATS->bh.pck_recv, EC_GBL_STATS->bh.pck_size);
    wdg_window_print(wdg_stats, 1, 9, "Top Half received packet    : pck: %8lld  bytes: %8lld", 
-         GBL_STATS->th.pck_recv, GBL_STATS->th.pck_size);
+         EC_GBL_STATS->th.pck_recv, EC_GBL_STATS->th.pck_size);
    wdg_window_print(wdg_stats, 1, 10, "Interesting packets         : %.2f %% ",
-         (GBL_STATS->bh.pck_recv) ? (float)GBL_STATS->th.pck_recv * 100 / GBL_STATS->bh.pck_recv : 0 );
+         (EC_GBL_STATS->bh.pck_recv) ? (float)EC_GBL_STATS->th.pck_recv * 100 / EC_GBL_STATS->bh.pck_recv : 0 );
 
    wdg_window_print(wdg_stats, 1, 12, "Bottom Half packet rate : worst: %8d  adv: %8d p/s", 
-         GBL_STATS->bh.rate_worst, GBL_STATS->bh.rate_adv);
+         EC_GBL_STATS->bh.rate_worst, EC_GBL_STATS->bh.rate_adv);
    wdg_window_print(wdg_stats, 1, 13, "Top Half packet rate    : worst: %8d  adv: %8d p/s", 
-         GBL_STATS->th.rate_worst, GBL_STATS->th.rate_adv);
+         EC_GBL_STATS->th.rate_worst, EC_GBL_STATS->th.rate_adv);
    
    wdg_window_print(wdg_stats, 1, 14, "Bottom Half throughput  : worst: %8d  adv: %8d b/s", 
-         GBL_STATS->bh.thru_worst, GBL_STATS->bh.thru_adv);
+         EC_GBL_STATS->bh.thru_worst, EC_GBL_STATS->bh.thru_adv);
    wdg_window_print(wdg_stats, 1, 15, "Top Half throughput     : worst: %8d  adv: %8d b/s", 
-         GBL_STATS->th.thru_worst, GBL_STATS->th.thru_adv);
+         EC_GBL_STATS->th.thru_worst, EC_GBL_STATS->th.thru_adv);
 }
 
 /*
