@@ -58,12 +58,7 @@ static void wdg_dynlist_border(struct wdg_object *wo);
 static void wdg_dynlist_move(struct wdg_object *wo, int key);
 static void wdg_dynlist_mouse(struct wdg_object *wo, int key, struct wdg_mouse_event *mouse);
 
-void wdg_dynlist_refresh(wdg_t *wo);
-void wdg_dynlist_print_callback(wdg_t *wo, void * func(int mode, void *list, char **desc, size_t len));
-void wdg_dynlist_select_callback(wdg_t *wo, void (*callback)(void *));
-void wdg_dynlist_add_callback(wdg_t *wo, int key, void (*callback)(void *));
 static int wdg_dynlist_callback(struct wdg_object *wo, int key);
-void wdg_dynlist_reset(wdg_t *wo);
 
 /*******************************************/
 
@@ -116,7 +111,7 @@ static int wdg_dynlist_destroy(struct wdg_object *wo)
 
    WDG_SAFE_FREE(wo->extend);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -126,7 +121,7 @@ static int wdg_dynlist_resize(struct wdg_object *wo)
 {
    wdg_dynlist_redraw(wo);
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -166,14 +161,14 @@ static int wdg_dynlist_redraw(struct wdg_object *wo)
 
       /* create the outher window */
       if ((ww->win = newwin(l, c, y, x)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
 
       /* draw the borders */
       wdg_dynlist_border(wo);
 
       /* create the inner (actual) window */
       if ((ww->sub = newwin(l - 4, c - 4, y + 2, x + 2)) == NULL)
-         return -WDG_EFATAL;
+         return -WDG_E_FATAL;
       
       /* set the window color */
       wbkgd(ww->sub, COLOR_PAIR(wo->window_color));
@@ -194,7 +189,7 @@ static int wdg_dynlist_redraw(struct wdg_object *wo)
    
    wo->flags |= WDG_OBJ_VISIBLE;
 
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -208,7 +203,7 @@ static int wdg_dynlist_get_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_dynlist_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -222,7 +217,7 @@ static int wdg_dynlist_lost_focus(struct wdg_object *wo)
    /* redraw the window */
    wdg_dynlist_redraw(wo);
    
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /* 
@@ -242,7 +237,7 @@ static int wdg_dynlist_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_
             else
                wdg_set_focus(wo);
          } else 
-            return -WDG_ENOTHANDLED;
+            return -WDG_E_NOTHANDLED;
          break;
       
       case KEY_UP:
@@ -263,7 +258,7 @@ static int wdg_dynlist_get_msg(struct wdg_object *wo, int key, struct wdg_mouse_
          break;
    }
   
-   return WDG_ESUCCESS;
+   return WDG_E_SUCCESS;
 }
 
 /*
@@ -366,11 +361,11 @@ static int wdg_dynlist_callback(struct wdg_object *wo, int key)
          if (ww->current)
             WDG_EXECUTE(c->callback, ww->current);
          
-         return WDG_ESUCCESS;
+         return WDG_E_SUCCESS;
       }
    }
 
-   return -WDG_ENOTHANDLED;
+   return -WDG_E_NOTHANDLED;
 }
 
 
@@ -557,6 +552,9 @@ static void wdg_dynlist_mouse(struct wdg_object *wo, int key, struct wdg_mouse_e
    size_t y = wdg_get_begin_y(wo) + 2;
    size_t line, i = 0;
    void *next;
+
+   /* variable currently not used */
+   (void) key;
    
    /* calculate which line was selected */
    line = mouse->y - y;
