@@ -150,7 +150,8 @@ static void gtkui_fatal_error_wrap(const char *msg) {
 
    char *copy = strdup(msg);
    if (msg) {
-      g_idle_add(gtkui_fatal_error_shim, copy);
+      gtkui_fatal_error_shim(copy);
+      //g_idle_add(gtkui_fatal_error_shim, copy);
    } else {
       FATAL_ERROR("out of memory");
    }
@@ -719,6 +720,9 @@ void gtkui_start(void)
       gtkui_sniff_offline();
    else
       gtkui_sniff_live();
+
+   /* start plugins defined on CLI */
+   g_idle_add(gtkui_plugins_autostart, NULL);
    
    /* the main gui loop, once this exits the gui will be destroyed */
    gtk_main();
@@ -1266,7 +1270,6 @@ static void gtkui_unified_sniff(void)
  */
 static void gtkui_unified_sniff_default(void) 
 {
-   char err[PCAP_ERRBUF_SIZE];
    
    DEBUG_MSG("gtkui_unified_sniff_default");
 
@@ -1275,8 +1278,8 @@ static void gtkui_unified_sniff_default(void)
       char *iface;
 
       SAFE_CALLOC(EC_GBL_OPTIONS->iface, IFACE_LEN, sizeof(char));
-      iface = pcap_lookupdev(err);
-      ON_ERROR(iface, NULL, "pcap_lookupdev: %s", err);
+      iface = capture_default_if();
+      ON_ERROR(iface, NULL, "No suitable interface found....");
    
       strncpy(EC_GBL_OPTIONS->iface, iface, IFACE_LEN - 1);
    }
@@ -1693,7 +1696,7 @@ void gtkui_page_close_current(void) {
    gtkui_page_close(NULL, child);
 }
 
-/* show the context menu when the notebook tabs recieve a mouse right-click */
+/* show the context menu when the notebook tabs receive a mouse right-click */
 gboolean gtkui_context_menu(GtkWidget *widget, GdkEventButton *event, gpointer data) {
    /* variable not used */
    (void) widget;
@@ -1787,7 +1790,7 @@ char *gtkui_utf8_validate(char *data) {
 
    unicode = data;
    if(!g_utf8_validate (data, -1, &end)) {
-      /* if "end" pointer is at begining of string, we have no valid text to print */
+      /* if "end" pointer is at beginning of string, we have no valid text to print */
       if(end == unicode) return(NULL);
 
       /* cut off the invalid part so we don't lose the whole string */
