@@ -22,12 +22,6 @@
 #include <ec.h>
 #include <ec_gtk.h>
 
-/* globals */
-
-/* proto */
-
-void gtkui_sniff_live(void);
-
 /*******************************************/
 
 
