@@ -30,7 +30,7 @@ void gtkui_start_sniffing(void)
    DEBUG_MSG("gtk_start_sniffing");
    
    /* start the sniffing method */
-   EXECUTE(GBL_SNIFF->start);
+   EXECUTE(EC_GBL_SNIFF->start);
 }
 
 void gtkui_stop_sniffing(void)
@@ -38,7 +38,7 @@ void gtkui_stop_sniffing(void)
    DEBUG_MSG("gtk_stop_sniffing");
    
    /* terminate the sniffing engine */
-   EXECUTE(GBL_SNIFF->cleanup);
+   EXECUTE(EC_GBL_SNIFF->cleanup);
 }
 
 
