@@ -155,7 +155,8 @@ static void gtkui_fatal_error_wrap(const char *msg) {
 
    char *copy = strdup(msg);
    if (msg) {
-      g_idle_add(gtkui_fatal_error_shim, copy);
+      gtkui_fatal_error_shim(copy);
+      //g_idle_add(gtkui_fatal_error_shim, copy);
    } else {
       FATAL_ERROR("out of memory");
    }
@@ -927,6 +928,9 @@ void gtkui_start(void)
 
    /* create second instance of the UI application */
    etterapp = gtkui_setup(gtkui_create_menu, GINT_TO_POINTER(online));
+
+   /* start plugins defined on CLI */
+   g_idle_add(gtkui_plugins_autostart, NULL);
    
    /* the main gui loop, once this exits the gui will be destroyed */
    g_application_run(G_APPLICATION(etterapp), 0, NULL);
@@ -1773,7 +1777,7 @@ void gtkui_page_close_current(GSimpleAction *action, GVariant *value, gpointer d
    gtkui_page_close(NULL, child);
 }
 
-/* show the context menu when the notebook tabs recieve a mouse right-click */
+/* show the context menu when the notebook tabs receive a mouse right-click */
 gboolean gtkui_context_menu(GtkWidget *widget, GdkEventButton *event, gpointer data) {
    /* variable not used */
    (void) widget;
@@ -1883,7 +1887,7 @@ char *gtkui_utf8_validate(char *data) {
 
    unicode = data;
    if(!g_utf8_validate (data, -1, &end)) {
-      /* if "end" pointer is at begining of string, we have no valid text to print */
+      /* if "end" pointer is at beginning of string, we have no valid text to print */
       if(end == unicode) return(NULL);
 
       /* cut off the invalid part so we don't lose the whole string */
