@@ -106,25 +106,19 @@ void gtkui_sslredir_show(GSimpleAction *action, GVariant *value, gpointer data)
    renderer = gtk_cell_renderer_text_new();
    column = gtk_tree_view_column_new_with_attributes("IP Version", renderer,
          "text", 1, NULL);
-   gtk_tree_view_column_set_sort_column_id(column, 0);
-   gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
-
-   renderer = gtk_cell_renderer_text_new();
-   column = gtk_tree_view_column_new_with_attributes("Source", renderer,
-         "text", 2, NULL);
    gtk_tree_view_column_set_sort_column_id(column, 1);
    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
    renderer = gtk_cell_renderer_text_new();
-   column = gtk_tree_view_column_new_with_attributes("Destination", renderer,
-         "text", 3, NULL);
+   column = gtk_tree_view_column_new_with_attributes("Server IP", renderer,
+         "text", 2, NULL);
    gtk_tree_view_column_set_sort_column_id(column, 2);
    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
    renderer = gtk_cell_renderer_text_new();
    column = gtk_tree_view_column_new_with_attributes("Service", renderer,
-         "text", 7, NULL);
-   gtk_tree_view_column_set_sort_column_id(column, 3);
+         "text", 6, NULL);
+   gtk_tree_view_column_set_sort_column_id(column, 6);
    gtk_tree_view_append_column(GTK_TREE_VIEW(treeview), column);
 
    gtkui_sslredir_create_lists();
@@ -182,17 +176,16 @@ void gtkui_sslredir_show(GSimpleAction *action, GVariant *value, gpointer data)
 static void gtkui_sslredir_add(GtkWidget *widget, gpointer data)
 {
 
-   GtkWidget *dialog, *content, *grid, *source, *destination, *label, *frame;
+   GtkWidget *dialog, *content, *grid, *destination, *label, *frame;
    GtkWidget *proto, *af;
    GtkTreeModel *model;
    GtkTreeIter iter;
    GtkCellRenderer *cell1, *cell2;
-   GtkWidget *entry_widgets[2];
    GVariant *gv_from_port, *gv_to_port;
    int ret = 0;
    guint16 from_port, to_port;
    gchar *name;
-   const gchar *from, *to;
+   const gchar *server;
    ec_redir_proto_t ip_ver;
 
    /* unused variabled */
@@ -255,27 +248,17 @@ static void gtkui_sslredir_add(GtkWidget *widget, gpointer data)
          "text", 0, NULL);
    gtk_grid_attach(GTK_GRID(grid), af, GTK_POS_LEFT+1, GTK_POS_TOP, 1, 1);
 
-   label = gtk_label_new("Source:");
+   label = gtk_label_new("Server IP:");
    gtk_widget_set_halign(label, GTK_ALIGN_START);
    gtk_grid_attach(GTK_GRID(grid), label, GTK_POS_LEFT, GTK_POS_TOP+1, 1, 1);
 
-   source = gtk_entry_new();
-   gtk_entry_set_text(GTK_ENTRY(source), "0.0.0.0/0");
-   gtk_widget_grab_focus(source);
-   gtk_widget_activate(source);
-   gtk_grid_attach(GTK_GRID(grid), source, GTK_POS_LEFT+1, GTK_POS_TOP+1, 1, 1);
-
-   label = gtk_label_new("Destination:");
-   gtk_widget_set_halign(label, GTK_ALIGN_START);
-   gtk_grid_attach(GTK_GRID(grid), label, GTK_POS_LEFT, GTK_POS_TOP+2, 1, 1);
-
    destination = gtk_entry_new();
    gtk_entry_set_text(GTK_ENTRY(destination), "0.0.0.0/0");
-   gtk_grid_attach(GTK_GRID(grid), destination, GTK_POS_LEFT+1, GTK_POS_TOP+2, 1, 1);
+   gtk_grid_attach(GTK_GRID(grid), destination, GTK_POS_LEFT+1, GTK_POS_TOP+1, 1, 1);
 
    label = gtk_label_new("Service:");
    gtk_widget_set_halign(label, GTK_ALIGN_START);
-   gtk_grid_attach(GTK_GRID(grid), label, GTK_POS_LEFT, GTK_POS_TOP+3, 1, 1);
+   gtk_grid_attach(GTK_GRID(grid), label, GTK_POS_LEFT, GTK_POS_TOP+2, 1, 1);
 
    proto = gtk_combo_box_new();
    gtk_combo_box_set_model(GTK_COMBO_BOX(proto), GTK_TREE_MODEL(proto_list));
@@ -285,14 +268,13 @@ static void gtkui_sslredir_add(GtkWidget *widget, gpointer data)
    gtk_cell_layout_pack_start(GTK_CELL_LAYOUT(proto), cell2, TRUE);
    gtk_cell_layout_set_attributes(GTK_CELL_LAYOUT(proto), cell2, 
          "text", 1, NULL);
-   gtk_grid_attach(GTK_GRID(grid), proto, GTK_POS_LEFT+1, GTK_POS_TOP+3, 1, 1);
+   gtk_grid_attach(GTK_GRID(grid), proto, GTK_POS_LEFT+1, GTK_POS_TOP+2, 1, 1);
 
-   entry_widgets[0] = source;
-   entry_widgets[1] = destination;
    g_signal_connect(G_OBJECT(af), "changed", 
-         G_CALLBACK(gtkui_sslredir_af_changed), entry_widgets);
+         G_CALLBACK(gtkui_sslredir_af_changed), destination);
 
    gtk_widget_show_all(dialog);
+   gtk_widget_grab_focus(destination);
 
    if (gtk_dialog_run(GTK_DIALOG(dialog)) == GTK_RESPONSE_OK) {
       gtk_widget_hide(dialog);
@@ -311,12 +293,11 @@ static void gtkui_sslredir_add(GtkWidget *widget, gpointer data)
       from_port = g_variant_get_uint16(gv_from_port);
       to_port = g_variant_get_uint16(gv_to_port);
 
-      from = gtk_entry_get_text(GTK_ENTRY(source));
-      to = gtk_entry_get_text(GTK_ENTRY(destination));
+      server = gtk_entry_get_text(GTK_ENTRY(destination));
 
       /* execute redirect action */
       ret = ec_redirect(EC_REDIR_ACTION_INSERT, name, ip_ver,
-            from, to, from_port, to_port);
+            server, from_port, to_port);
 
 
       /* inform user if redirect execution wasn't successful */
@@ -329,12 +310,11 @@ static void gtkui_sslredir_add(GtkWidget *widget, gpointer data)
          gtk_list_store_set(redirrules, &iter,
                0, ip_ver,
                1, (ip_ver == EC_REDIR_PROTO_IPV4 ? "IPv4" : "IPv6"),
-               2, from,
-               3, to,
-               4, gv_from_port,
-               5, gv_to_port,
-               6, ec_strlc(name),
-               7, ec_struc(name),
+               2, server,
+               3, gv_from_port,
+               4, gv_to_port,
+               5, ec_strlc(name),
+               6, ec_struc(name),
                -1);
       }
       
@@ -357,7 +337,7 @@ void gtkui_sslredir_del(GtkWidget *widget, gpointer data)
    GVariant *gv_from_port, *gv_to_port;
    int ret;
    gchar *name;
-   const gchar *from, *to;
+   const gchar *server;
    guint16 from_port, to_port;
    ec_redir_proto_t ip_ver;
 
@@ -376,11 +356,10 @@ void gtkui_sslredir_del(GtkWidget *widget, gpointer data)
          gtk_tree_model_get_iter(model, &iter, list->data);
          gtk_tree_model_get(model, &iter, 
                0, &ip_ver,
-               2, &from,
-               3, &to,
-               4, &gv_from_port,
-               5, &gv_to_port,
-               6, &name,
+               2, &server,
+               3, &gv_from_port,
+               4, &gv_to_port,
+               5, &name,
                -1);
 
          /* convert back from GVariant to uint16 */
@@ -389,7 +368,7 @@ void gtkui_sslredir_del(GtkWidget *widget, gpointer data)
 
          /* execute redirect action */
          ret = ec_redirect(EC_REDIR_ACTION_REMOVE, name, ip_ver,
-               from, to, from_port, to_port);
+               server, from_port, to_port);
 
          /* inform user if redirect execution wasn't successful */
          if (ret != E_SUCCESS)
@@ -465,10 +444,9 @@ static void gtkui_sslredir_create_lists(void)
 
    /* populate redirect rules */
    if (redirrules == NULL) {
-      redirrules = gtk_list_store_new(8,
+      redirrules = gtk_list_store_new(7,
             G_TYPE_UINT,    /* IP address family */
             G_TYPE_STRING,  /* IP address family human readable */
-            G_TYPE_STRING,  /* source definition */
             G_TYPE_STRING,  /* destination definition */
             G_TYPE_VARIANT, /* protocol registered port */
             G_TYPE_VARIANT, /* ettercap listener port */
@@ -549,12 +527,11 @@ static void gtkui_sslredir_add_list(struct redir_entry *re)
    gtk_list_store_set(redirrules, &iter,
          0, re->proto,
          1, (re->proto == EC_REDIR_PROTO_IPV4 ? "IPv4" : "IPv6"),
-         2, re->source,
-         3, re->destination,
-         4, gv_from_port,
-         5, gv_to_port,
-         6, ec_strlc(re->name),
-         7, ec_struc(re->name),
+         2, re->destination,
+         3, gv_from_port,
+         4, gv_to_port,
+         5, ec_strlc(re->name),
+         6, ec_struc(re->name),
          -1);
 
 }
@@ -566,12 +543,10 @@ static void gtkui_sslredir_add_list(struct redir_entry *re)
  */
 void gtkui_sslredir_af_changed(GtkWidget *widget, gpointer data)
 {
-   GtkWidget **widgets;
    GtkTreeModel *model;
    GtkTreeIter iter;
    ec_redir_proto_t proto;
 
-   widgets = data;
 
    model = gtk_combo_box_get_model(GTK_COMBO_BOX(widget));
    gtk_combo_box_get_active_iter(GTK_COMBO_BOX(widget), &iter);
@@ -579,14 +554,12 @@ void gtkui_sslredir_af_changed(GtkWidget *widget, gpointer data)
 
    switch (proto) {
       case EC_REDIR_PROTO_IPV4:
-         gtk_entry_set_text(GTK_ENTRY(widgets[0]), "0.0.0.0/0");
-         gtk_entry_set_text(GTK_ENTRY(widgets[1]), "0.0.0.0/0");
-         gtk_widget_grab_focus(widgets[0]);
+         gtk_entry_set_text(GTK_ENTRY(data), "0.0.0.0/0");
+         gtk_widget_grab_focus(data);
          break;
       case EC_REDIR_PROTO_IPV6:
-         gtk_entry_set_text(GTK_ENTRY(widgets[0]), "::/0");
-         gtk_entry_set_text(GTK_ENTRY(widgets[1]), "::/0");
-         gtk_widget_grab_focus(widgets[0]);
+         gtk_entry_set_text(GTK_ENTRY(data), "::/0");
+         gtk_widget_grab_focus(data);
          break;
       default:
          break;
