@@ -2,9 +2,12 @@
 #include <check.h>
 
 #include <ec.h>
+#include <ec_libettercap.h>
 #include <ec_decode.h>
 #include <ec_proto.h>
 
+struct ec_globals *ec_gbls;
+
 // Yes, this is hack-ish. We can change it later.
 
 START_TEST (test_get_decoder_default)
@@ -44,6 +47,7 @@ Suite* ts_test_decode (void) {
 
 int main () {
   int number_failed;
+  libettercap_init("test", "0.0.1");
   Suite *suite = ts_test_decode();
   SRunner *runner = srunner_create(suite);
   srunner_run_all(runner, CK_VERBOSE);
